mafw.mafw\_errors
=================

.. automodule:: mafw.mafw_errors

   
   .. rubric:: Exceptions

   .. autosummary::
   
      AbortProcessorException
      InvalidSteeringFile
      MAFwException
      MissingAttribute
      MissingDatabase
      MissingOptionalDependency
      MissingOverloadedMethod
      MissingSQLStatement
      MissingSuperCall
      ModelError
      ParserConfigurationError
      ParsingError
      PlotterMixinNotInitialized
      ProcessorParameterError
      RunnerNotInitialized
      UnknownDBEngine
      UnknownProcessor
   